@@ -7,12 +7,14 @@ library(aws.polly)
 
 if (nzchar(Sys.getenv("AWS_ACCESS_KEY_ID"))) {
   if (!identical(Sys.getenv("TRAVIS"), "true")) {
-      aws.signature::use_credentials(profile = "polly")
+    aws.signature::use_credentials(profile = "polly")
   }
 }
 skip_amazon_not_authorized = function() {
-  if (text2speech::tts_amazon_authenticated()) {
-    return(invisible(TRUE))
+  if (requireNamespace("aws.polly", quietly = TRUE)) {
+    if (text2speech::tts_amazon_authenticated()) {
+      return(invisible(TRUE))
+    }
   }
   skip("Amazon not authenticated()")
 }
